==> otyacraftengine-forge-3.0-sources.jar: dev/felnull/otyacraftengine/explatform/OETagsExpectPlatform.java <==
package dev.felnull.otyacraftengine.explatform;

import dev.architectury.injectables.annotations.ExpectPlatform;
import dev.felnull.otyacraftengine.tag.ManualTagHolder;
import net.minecraft.tags.TagKey;
import net.minecraft.world.item.Item;

public class OETagsExpectPlatform {
    @ExpectPlatform
    public static TagKey<Item> pickaxes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> shovels() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> hoes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> axes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> shears() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> swords() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> bows() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> ironIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> goldIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> copperIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> netheriteIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> redstoneDusts() {
        throw new AssertionError();

    }

    @ExpectPlatform
    public static TagKey<Item> diamonds() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> glassBlocks() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> glassPanes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> books() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> ironNuggets() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> enderPearls() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> stone() {
        throw new AssertionError();

    }

    @ExpectPlatform
    public static ManualTagHolder<Item> redstoneBlocks() {
        throw new AssertionError();
    }
}

==> otyacraftengine-forge-3.2.0-pre.5-sources.jar: dev/felnull/otyacraftengine/explatform/OETagsExpectPlatform.java <==
package dev.felnull.otyacraftengine.explatform;

import dev.architectury.injectables.annotations.ExpectPlatform;
import dev.felnull.otyacraftengine.tag.ManualTagHolder;
import net.minecraft.tags.TagKey;
import net.minecraft.world.item.Item;

public class OETagsExpectPlatform {
    @ExpectPlatform
    public static TagKey<Item> pickaxes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> shovels() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> hoes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> axes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> shears() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> swords() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> bows() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> ironIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> goldIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> copperIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> netheriteIngots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> redstoneDusts() {
        throw new AssertionError();

    }

    @ExpectPlatform
    public static TagKey<Item> diamonds() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> glassBlocks() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> glassPanes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static TagKey<Item> books() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> ironNuggets() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> enderPearls() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> stone() {
        throw new AssertionError();

    }

    @ExpectPlatform
    public static ManualTagHolder<Item> redstoneBlocks() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> rawMeats() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> cookedMeats() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> rawFishes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> cookedFishes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> wheatBreads() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> breads() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> vegetables() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> carrots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> potatoes() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> beetroots() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> wheatGrains() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> grains() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> seeds() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> fruits() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> milks() {
        throw new AssertionError();
    }

    @ExpectPlatform
    public static ManualTagHolder<Item> drinks() {
        throw new AssertionError();
    }
}
